@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2004
+// Copyright (C) 1999-2012
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -11,7 +11,6 @@
 class FitsHist : public FitsFile {
  public:
   enum Function {SUM, AVERAGE};
-  enum Smooth {BOXCAR, TOPHAT, GAUSSIAN};
 
  private:
   int width;
@@ -26,23 +25,28 @@ class FitsHist : public FitsFile {
   void* fitsy;
   void* filter;
 
-  int initHeader(FitsFile*, Matrix&);
+  int initHeader(FitsFile*);
   void initLTMV(Matrix&);
   void initWCS(FitsFile*, Matrix&, Vector);
-  void initWCSAlt(FitsFile*, Matrix&, Vector);
+  void mapWCSMatrix(FitsHead*, char* w, const char* out, const char* in, 
+		    Vector);
+  void mapWCSReal(FitsHead* head, const char* out, const char* in);
+  void mapWCSReal(FitsHead* head, char* w, const char* out, const char* in);
+  void mapWCSReal(FitsHead*, char* w, 
+		  const char* out, const char* prim, const char* alt, 
+		  Matrix);
+  void mapWCSString(FitsHead*, char* w, const char* out, const char* prim);
+  void mapWCSString(FitsHead*, char* w, 
+		    const char* out, const char* prim, const char* alt);
+  void mapWCSVector(FitsHead*, char* w, const char* out, const char* in);
   void initFilter(FitsFile*);
   void deleteFilter();
   void bin(FitsFile*, Matrix&, Function, Vector);
-  void boxcar(int);
-  void tophat(int);
-  void gaussian(int);
-  void convolve(float*, int);
   void swap();
 
  public:
   FitsHist(FitsFile* src, int width, int height, int depth, 
-	   Matrix& m, Function func, Vector block, 
-	   int sm, Smooth smf, int size);
+	   Matrix& m, Function func, Vector block);
   ~FitsHist();
 };
 
