@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2004
+// Copyright (C) 1999-2012
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -6,57 +6,53 @@
 #define __contour_h__
 
 #include "vector.h"
+#include "vector3d.h"
 #include "list.h"
-#include "contourscale.h"
+#include "coord.h"
 
 class FitsImage;
-class FrameBase;
-
-static char *methodName[] = { 
-  "smooth",
-  "block"
-};
+class Base;
 
 class Contour {
- public:
-  enum Method {SMOOTH, BLOCK};
-
  protected:
-  FrameBase* parent;
+  Base* parent;
   List<Vertex> contours_;
 
   char* colorName;
-  int color;
+  unsigned long color;
   int lineWidth;
-
-  ContourScale* scale;
-  Method method;
+  int dash;
+  int dashlist[2];
 
   Contour* previous_;
   Contour* next_;
 
  public:
-  Contour(FrameBase*, const char*, int, int);
-  Contour(FrameBase*, const char*, int, const List<Vertex>&);
+  Contour(Base*, const char*, int, int);
+  Contour(Base*, const char*, int, int, const List<Vertex>&);
   virtual ~Contour();
 
-  void render(Pixmap, const Matrix&, const BBox&);
+  void render(Pixmap, Coord::InternalSystem, int, int);
   void ps(int);
+#ifdef _MACOSX
+  void macosx();
+#endif
+#ifdef _WIN32
+  void win32();
+#endif
+
   const List<Vertex>& contours() {return contours_;}
   void updateCoords(const Matrix&);
 
   const char* getColorName() {return colorName;}
   void setColor(const char*);
 
+  int getDash() {return dash;}
+  void setDash(int);
+
   void setLineWidth(int);
   int getLineWidth() {return lineWidth;}
 
-  virtual void append(FitsImage*) {}
-  ContourScale* getScale() {return scale;}
-
-  int getMethod() {return method;}
-  const char* getMethodName() {return methodName[method];}
-
   Contour* previous() {return previous_;}
   void setPrevious(Contour* m) {previous_ = m;}
   Contour* next() {return next_;}
@@ -64,7 +60,3 @@ class Contour {
 };
 
 #endif
-
-
-
-
