@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2004
+// Copyright (C) 1999-2012
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -27,11 +27,7 @@ private:
 public:
   Magnifier(Tcl_Interp*, Tk_Canvas, Tk_Item*);
 
-#if __GNUC__ >= 3
   int parse(istringstream&);          // parse subcommands
-#else
-  int parse(istrstream&);          // parse subcommands
-#endif
 
   // SubCommandFunctions
 
